<TS language="szl" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Zrychtuj nowõ adresã</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Skopiyruj aktualnie ôbranõ adresã do skrytki</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiyruj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zawrzij</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Wychrōń zaznaczōnõ adresã z brify</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Wkludź adresã abo etyketã coby wyszukać</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksportuj dane z aktywnyj szkarty do zbioru</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportuj</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Wychrōń</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Ôbier adresã, na kerõ chcesz posłać mōnety</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Ôbier adresã, na kerõ chcesz dostać mōnety</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Ô&amp;bier</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adresy posyłaniŏ</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adresy ôdbiyraniŏ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Tukej sōm adresy Bitcoin na kere posyłŏsz płaty. Dycki wybaduj wielość i adresã ôdbiyrŏcza przed posłaniym mōnet.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopiyruj Adresã</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiyruj &amp;Etyketã</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edytuj</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksportuj wykŏz adres</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Zbiōr *.CSV (daty rozdzielane kōmami)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportowanie niy podarziło sie</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Przitrefiōł sie feler w czasie spamiyntowaniŏ brify adres do %1. Proszã sprōbować zaś.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etyketa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chyba etykety)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Ôkiynko Hasła</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Wkludź hasło</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nowe hasło</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Powtōrz nowe hasło</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Zaszyfruj portmanyj</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ta ôperacyjŏ wymŏgŏ hasła do portmanyja coby ôdszperować portmanyj.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ôdszperuj portmanyj.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ta ôperacyjŏ wymŏgŏ hasła do portmanyja coby ôdszyfrować portmanyj.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Ôdszyfruj portmanyj</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Pōmiyń hasło</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Przituplikuj szyfrowanie portmanyja</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Pozōr: jeźli zaszyfrujesz swōj portmanyj i stracisz hasło &lt;b&gt;STRACISZ WSZYJSKE SWOJE BITCOINY&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Na isto chcesz zaszyfrować swōj portmanyj?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portmanyj zaszyfrowany</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Wkludź nowe hasło do portmanyja.&lt;br/&gt;Proszã używać hasła słożōnego z &lt;b&gt;10 abo wiyncyj losowych liter&lt;/b&gt; abo &lt;b&gt;8 abo wiyncyj słōw.&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Podej stare i nowe hasło do portmanyja.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>WŎŻNE: Wszyjske wykōnane wczaśnij kopije zbioru portmanyja winny być umiyniōne na nowe, szyfrowane zbiory. Z powodōw bezpiyczyństwa, piyrwyjsze kopije niyszyfrowanych zbiorōw portmanyja stōnõ sie bezużyteczne jak ino zaczniesz używać nowego, szyfrowanego portmanyja.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Zaszyfrowanie portmanyja niy podarziło sie</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Zaszyfrowanie portmanyja niy podarziło sie bez wnyntrzny feler. Twōj portmanyj niy ôstoł zaszyfrowany.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Podane hasła niy sōm take same.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Ôdszperowanie portmanyja niy podarziło sie</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Wkludzōne hasło do ôdszyfrowaniŏ portmanyja je niynŏleżne.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Ôdszyfrowanie portmanyja niy podarziło sie</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Hasło do portmanyja ôstało sprŏwnie pōmiyniōne.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Pozōr: Caps Lock je zapuszczōny!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Maska necu</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Szpera do</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Szkryftnij &amp;wiadōmość</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchrōnizacyjŏ z necym...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Podsumowanie</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Pokazuje ôgōlny widok portmanyja</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcyje</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Przeglōndej historyjõ transakcyji</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Zakōńcz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Zawrzij aplikacyjõ</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Ô %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Pokŏż informacyje ô %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Ô &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Pokŏż informacyje ô Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Ô&amp;pcyje...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Zmiyń ôpcyje kōnfiguracyje dlŏ %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Zaszyfruj Portmanyj...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Zrychtuj kopijõ ibrycznõ</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Pōmiyń &amp;hasło</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Ôdewrzij &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Portmanyj:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Aktywność necowŏ ôstała zastawiōnŏ.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Synchrōnizowanie nŏgōwkōw (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Pōnowne indeksowanie blokōw na dysku...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>Proxy je &lt;b&gt;zapuszczone&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Poślij mōnety na adresã Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Ibryczny portmanyj w inkszyj lokalizacyje</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Pōmiyń hasło użyte do szyfrowaniŏ portmanyja</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Weryfikuj wiadōmość...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Poślij</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Ôd&amp;bier</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Pokŏż / &amp;Skryj</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Pokazuje abo skrywŏ bazowe ôkno</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Szyfruj klucze prywatne, kere sōm we twojim portmanyju</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Podpisz wiadōmości swojōm adresōm coby dowiyść jejich posiadanie</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Zweryfikuj wiadōmość, coby wejzdrzeć sie, iże ôstała podpisanŏ podanōm adresōm Bitcoin.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Zbiōr</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nasztalowania</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pō&amp;moc</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Lajsta szkart</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Żōndej płatu (gyneruje kod QR jak tyż URI bitcoin:)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Pokŏż wykŏz adres i etyket użytych do posyłaniŏ</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Pokŏż wykŏz adres i etyket użytych do ôdbiyraniŏ</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>Ôp&amp;cyje piski nakŏzań</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indeksowanie blokōw na dysku...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Przetwŏrzanie blokōw na dysku...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>Przetworzōno %n blok historyji transakcyji.</numerusform><numerusform>Przetworzōno %n blokōw historyji transakcyji.</numerusform><numerusform>Przetworzōno %n blokōw historyji transakcyji.</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 za</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ôstatni dostany blok ôstoł wygynerowany %1 tymu.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transakcyje po tym mōmyncie niy bydōm jeszcze widzialne.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Pozōr</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacyjŏ</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Terŏźny</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Ôdewrzij kōnsolã debugowaniŏ i diagnostyki</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;Adresy posyłaniŏ</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Adresy ôdbiyraniŏ</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>Pokŏż pōmoc %1 coby zobŏczyć wykŏz wszyjskich ôpcyji piski nakŏzań.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>Ô&amp;kno</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijynt</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform>%n aktywne połōnczynie do necu Bitcoin</numerusform><numerusform>%n aktywnych połōnczyń do necu Bitcoin</numerusform><numerusform>%n aktywnych skuplowań do necu Bitcoin</numerusform><numerusform>%n aktywne połōnczynie do necu Bitcoin</numerusform><numerusform>%n aktywnych połōnczyń do necu Bitcoin</numerusform><numerusform>%n aktywnych skuplowań do necu Bitcoin</numerusform></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Trwŏ synchrōnizacyjŏ...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feler: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datōm: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Kwota: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>Portmanyj: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Zorta: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etyketa: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transakcyjŏ wysłanŏ</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transakcyjŏ przichodzōncŏ</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>Gynerowanie kluczy HD je &lt;b&gt;zapuszczone&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Gynerowanie kluczy HD je &lt;b&gt;zastawiōne&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Portmanyj je &lt;b&gt;zaszyfrowany&lt;/b&gt; i terŏźnie &lt;b&gt;ôdszperowany&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portmanyj je &lt;b&gt;zaszyfrowany&lt;/b&gt; i terŏźnie &lt;b&gt;zaszperowany&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>Przitrefiōł sie krytyczny feler. %1 niy poradzi kōntynuować bezpiycznie i ôstanie zawrzity.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Ôbiōr mōnet</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Wielość:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtōw:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kwota:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ôpłŏcka:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Sztaub:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po ôpłŏcce:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Wydŏwka:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>Zaznacz/Ôdznacz wszyjsko</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Tryb strōma</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Tryb wykŏzu</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kwota</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ôdebrane z etyketōm</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ôdebrane z adresōm</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datōm</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Przituplowania</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Przituplowany</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiyruj kwotã</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiyruj adresã</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopiyruj &amp;etyketã</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiyruj kwotã</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopiyruj ID transakcyje</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Zaszperuj niywydane</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Ôdszperuj niywydane</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiyruj wielość</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiyruj ôpłŏckã</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiyruj wielość po ôpłŏcce</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiyruj wielość bajtōw</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiyruj sztaub</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiyruj wydŏwkã</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 zaszperowane)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>niy</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Ta etyketa stŏwŏ sie czyrwōnŏ jeźli keryś z ôdbiyrŏczy dostŏwŏ kwotã myńszõ aniżeli terŏźny prōg sztaubu.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Chwiyrŏ sie +/- %1 satoshi na wchōd.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chyba etykety)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>wydŏwka z %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(wydŏwka)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Portmanyj</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Zaszyfruj Portmanyj</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Edytuj adresã</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etyketa</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Etyketa ôbwiōnzanŏ z tym wpisym na wykŏzie adres</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Ta adresa je ôbwiōnzanŏ z wpisym na wykŏzie adres. Może być zmodyfikowany jyno dlŏ adres posyłajōncych.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nowŏ adresa posyłaniŏ</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Edytuj adresã ôdbiōru</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Edytuj adresã posyłaniŏ</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Wkludzōnŏ adresa "%1" niyma nŏleżnōm adresōm Bitcoin.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation>Adresa "%1" już je za adresã ôdbiorczõ z etyketōm "%2" i bez to niy idzie jeji przidać za adresã nadŏwcy.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation>Wkludzōnŏ adresa "%1" już je w ksiōnżce adres z ôpisym "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Niy idzie było ôdszperować portmanyja.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Gynerowanie nowego klucza niy podarziło sie.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Bydzie zrychtowany nowy folder danych.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>miano</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Katalog już je. Przidej %1 jeźli mŏsz zastrojynie zrychtować tukej nowy katalog.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Niy idzie było tukej zrychtować folderu datōw.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>wersyjŏ</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Ô %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Ôpcyje piski nakŏzań</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Witej</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Witej w %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Pōniywŏż je to piyrsze sztartniyńcie programu, możesz ôbrać kaj %1 bydzie spamiyntować swoje daty.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>Kej naciśniesz OK, %1 zacznie pobiyrać i przetwŏrzać cołkõ %4 keta blokōw (%2GB) przi zaczynaniu ôd piyrszych transakcyji w %3 kej %4 ôstoł sztartniynty.</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>Wstympnŏ synchrōnizacyjŏ je barzo wymŏgajōncŏ i może wyzdradzić wczaśnij niyzaôbserwowane niyprzileżytości sprzyntowe. Za kożdym sztartniyńciym %1 sebiyranie bydzie kōntynuowane ôd placu w kerym ôstało zastawiōne.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>Jeźli ôbrołś ôpcyjõ ukrōcyniŏ spamiyntowaniŏ kety blokōw (przicinanie) daty historyczne cołki czas bydōm musiały być sebrane i przetworzōne, jednak po tym ôstanõ wychrōniōne coby ôgraniczyć użycie dysku.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Użyj wychodnego folderu datōw</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Użyj ôbranego folderu datōw</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Co nojmynij %1 GB datōw ôstanie spamiyntane w tym katalogu, daty te bydōm z czasym corŏz srogsze.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>Kole %1 GB datōw ôstanie spamiyntane w tym katalogu.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation>%1 sebiere i spamiyntŏ kopijõ kety blokōw Bitcoin.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Portmanyj tyż ôstanie spamiyntany w tym katalogu.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Feler: podany folder datōw "%1" niy mōg ôstać zrychtowany.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB swobodnego placu dostympne</numerusform><numerusform>%n GB swobodnego placu dostympne</numerusform><numerusform>%n GB swobodnego placu dostympne</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation><numerusform>(z %n GB przidajnego)</numerusform><numerusform>(z %n GB przidajnych)</numerusform><numerusform>(z %n GB przidajnych)</numerusform></translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.</source>
        <translation>Świyże transakcyje mogōm niy być jeszcze widzialne, a tedyć saldo portmanyja może być niynŏleżne. Te detale bydōm nŏleżne, kej portmanyj zakōńczy synchrōnizacyjõ z necym bitcoin, zgodnie z miyniōnym ôpisym.</translation>
    </message>
    <message>
        <source>Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>Prōba wydaniŏ bitcoinōw kere niy sōm jeszcze wyświytlōne za transakcyjŏ ôstanie ôdciepniyntŏ bez nec.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Ôstało blokōw</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Niyznōme...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Czŏs ôstatnigo bloku</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postymp</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Przirost postympu na godzinã</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>ôbliczanie...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Przewidowany czŏs abszlusu synchrōnizacyje</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Skryj</translation>
    </message>
    <message>
        <source>Unknown. Syncing Headers (%1, %2%)...</source>
        <translation>Niyznōme. Synchrōnizowanie nŏgōwkōw (%1, %2%)...</translation>
    </message>
</context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Zorta</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>wychodny portmanyj</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Ôpcyje</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Bazowe</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Autōmatycznie sztartnij %1 po wlogowaniu do systymu.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Sztartuj %1 w czasie logowaniŏ do systymu</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Srogość bufōra bazy datōw</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Wielość wōntkōw &amp;weryfikacyje skryptu</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Adresa IP proxy (bp. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>Minimalizuje zamiast zakōńczyć fungowanie aplikacyje przi zawiyraniu ôkna. Kej ta ôpcyjŏ je zapuszczonŏ, aplikacyjŏ zakōńczy fungowanie po ôbraniu Zawrzij w myni.</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation>Ôdewrzij %1 zbiōr kōnfiguracyje z czynnego katalogu.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Ôdewrzij zbiōr kōnfiguracyje</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Prziwrōć wszyjske wychodne ustawiyniŏ klijynta.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Resetuj Ôpcyje</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Nec</translation>
    </message>
    <message>
        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
        <translation>Zastawiŏ niykere moderne funkcyje, ale wszyjske bloki durch bydōm w połni wybadowane. Cŏfniyńcie tego nasztalowaniŏ fołdruje pōnownego sebraniŏ cołkij kety blokōw. Istne spotrzebowanie dysku może być cosikej wyższe.</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation>Przitnij skłŏd &amp;blokōw do</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation>Cŏfniyńcie tego ustawiyniŏ fołdruje pōnownego sebraniŏ cołkij kety blokōw.</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation>(0 = autōmatycznie, &lt;0 = ôstŏw tela swobodnych drzyni)</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Portm&amp;anyj</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Ekspert</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Zapuść funkcyje kōntroli mōnet</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>Jeźli zastawisz możebność wydaniŏ niyprzituplikowanyj wydanej wydŏwki, wydŏwka z transakcyje niy bydzie mogła ôstać użytŏ, podwiela ta transakcyjŏ niy bydzie miała nojmynij jednego przituplowaniŏ. To tyż mŏ wpływ na porachowanie Twojigo salda.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Wydej niyprzituplowanõ wydŏwkã</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Autōmatycznie ôdewrzij port klijynta Bitcoin na routerze. Ta ôpcyjŏ funguje ino jeźli twōj router podpiyrŏ UPnP i je ôno zapuszczone.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapuj port przi używaniu &amp;UPnP</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation>Akceptuj skuplowania ôd zewnōntrz.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation>Zwōl na skuplowania przichodzōnce</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation>Skupluj sie z necym Bitcoin bez SOCKS5 proxy.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;Skupluj bez proxy SOCKS5 (wychodne proxy):</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port ôd proxy (bp. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>Ô&amp;kno</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Gŏdka &amp;używŏcza:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>Idzie sam nasztalować gŏdka interfejsu używŏcza. Nasztalowanie prziniesie skutki po resztarcie %1.</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
        <translation>Skupluj sie z necym Bitcoin ze pōmocōm ôsobnego proxy SOCKS5 dlŏ necu TOR</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Pociep</translation>
    </message>
    <message>
        <source>default</source>
        <translation>wychodny</translation>
    </message>
    <message>
        <source>none</source>
        <translation>żŏdyn</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Ôpcyje kōnfiguracyje</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Wyświytlanŏ informacyjŏ może być niyterŏźnŏ. Twōj portmanyj synchrōnizuje sie autōmatycznie z necym bitcoin zarŏz po tym, jak zrychtowane je skuplowanie, ale proces tyn niy ôstoł jeszcze skōńczōny.</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Dostympne:</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Czekajōnce:</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Salda</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Cuzamyn:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Twoje terŏźne saldo</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Zawrzij</translation>
    </message>
    <message>
        <source>or</source>
        <translation>abo</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Feler żōndaniŏ płatu</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Bedynōng URI</translation>
    </message>
    <message>
        <source>'bitcoin://' is not a valid URI. Use 'bitcoin:' instead.</source>
        <translation>'bitcoin://' to niyma nŏleżne URI. Użyj 'bitcoin:'.</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Agynt Używŏcza</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ôdebrane</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Zorta</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kwota</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>Wkludź adresã Bitcoin (bp. %1)</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Wchodowy</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feler: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>niyznōme</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Spamiyntej Ôbrŏzek</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Kopiyruj Ôbrŏzek</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Spamiyntej kod QR</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>Ôbrŏzek PNG (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Wersyjŏ klijynta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informacyjŏ</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>Używanie wersyje BerkeleyDB</translation>
    </message>
    <message>
        <source>Datadir</source>
        <translation>Katalog datōw</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Czŏs sztartniyńciŏ</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nec</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Miano</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Wielość skuplowań</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Keta blokōw</translation>
    </message>
    <message>
        <source>Current number of transactions</source>
        <translation>Terŏźniŏ wielość transakcyji</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation>Portmanyj:</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ôdebrane</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersyjŏ</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Agynt Używŏcza</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Usugi</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Czŏs Skuplowaniŏ</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Czas ôstatnigo bloku</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Ô&amp;dewrzij</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Ruch necowy</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Wchōd:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Wychōd:</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>Ô&amp;dkupluj</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Z</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Niy</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1 &amp;dziyń</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Kopiyruj adresã</translation>
    </message>
    <message>
        <source>Welcome to the %1 RPC console.</source>
        <translation>Witej w %1 kōnsoli RPC.</translation>
    </message>
    <message>
        <source>WARNING: Scammers have been active, telling users to type commands here, stealing their wallet contents. Do not use this console without fully understanding the ramifications of a command.</source>
        <translation>POZŌR: Machlyrze namŏwiajōm do wpisowaniŏ tukej roztōmajtych nakŏzań coby porwać portmanyj. Niy używej tyj kōnsole bez połnego zrozumiyniŏ wpisowanych nakŏzań.</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Aktywność necowŏ zastawiōnŏ</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Niyznōme</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Kwota:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etyketa:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Wiadōmość:</translation>
    </message>
    <message>
        <source>An optional message to attach to the payment request, which will be displayed when the request is opened. Note: The message will not be sent with the payment over the Bitcoin network.</source>
        <translation>Ôpcyjōnalnŏ wiadōmość do prziwstōniŏ do żōndaniŏ płatu, kerŏ bydzie wyświytlanŏ, kej żōndanie ôstanie ôdewrzōne. Napōmniynie: wiadōmość ta niy ôstanie wysłanŏ z płatym w nec Bitcoin.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wypucuj</translation>
    </message>
    <message>
        <source>Native segwit addresses (aka Bech32 or BIP-173) reduce your transaction fees later on and offer better protection against typos, but old wallets don't support them. When unchecked, an address compatible with older wallets will be created instead.</source>
        <translation>Natywne adresy segwit (aka Bech32 abo BIP-173) zmyńszajōm niyskorzij twoje ôpłŏcki za transakcyje i dadzōm lepsze zabezpieczynie przed chybami, ale stare portmanyje jejich niy podpiyrajōm. Jeźli ôdznaczōne, zrychtowanŏ ôstanie adresa kōmpatybilnŏ ze starszymi portmanyjami.</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Pokŏż</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Wychrōń</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopiyruj &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiyruj adresã</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopiyruj &amp;etyketã</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Kopiyruj wiadōmość</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiyruj kwotã</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Niy idzie było ôdszperować portmanyja.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adresa:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kwota:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Etyketa:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Wiadōmość:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Portmanyj:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopiyruj &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopiyruj &amp;Adresã</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Spamiyntej Ôbrozek</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Informacyje ô płacie</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datōm</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etyketa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadōmość</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chyba etykety)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Poślij mōnety</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Wielość:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtōw:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kwota:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Ôpłŏcka:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po ôpłŏcce:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Wydŏwka:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Ôbier...</translation>
    </message>
    <message>
        <source>Warning: Fee estimation is currently not possible.</source>
        <translation>Pozōr: Ôszacowanie ôpłŏcki za transakcyje je aktualnie niymożebne.</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>na kilobajt</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Skryj</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Doradzane:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>Włŏsne:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Sztaub:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Poślij</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiyruj wielość</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiyruj kwotã</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiyruj ôpłŏckã</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiyruj wielość po ôpłŏcce</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiyruj wielość bajtōw</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopiyruj sztaub</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiyruj wydŏwkã</translation>
    </message>
    <message>
        <source>%1 (%2 blocks)</source>
        <translation>%1 (%2 blokōw)</translation>
    </message>
    <message>
        <source>or</source>
        <translation>abo</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Poślij</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Utworzynie transakcyje niy podarziło sie!</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Pozōr: niynŏleżnŏ adresa Bitcoin</translation>
    </message>
    <message>
        <source>Warning: Unknown change address</source>
        <translation>Pozōr: Niyznōmŏ adresa wydŏwki</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chyba etykety)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Kwota:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etyketa:</translation>
    </message>
    <message>
        <source>The Bitcoin address to send the payment to</source>
        <translation>Adresa Bitcoin, na kerõ chcesz posłać płat</translation>
    </message>
    <message>
        <source>Use available balance</source>
        <translation>Użyj dostympnego salda</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Wiadōmość:</translation>
    </message>
    <message>
        <source>A message that was attached to the bitcoin: URI which will be stored with the transaction for your reference. Note: This message will not be sent over the Bitcoin network.</source>
        <translation>Wiadōmość, kerŏ ôstała prziwstōnŏ do URI bitcoin:, kerŏ bydzie przechowowanŏ z transakcyjōm w cylach informacyjnych. Napōmniynie: Ta wiadōmość niy bydzie rozszyrzowanŏ w necu Bitcoin.</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Szkryfki - Podpisz / Zweryfikuj Wiadōmość</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Szkryftnij Wiadōmość</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Szkryftnij &amp;Wiadōmość</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Weryfikuj Wiadōmość</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">&amp;Weryfikuj Wiadōmość</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Szkryftniyńcie wiadōmości niy podarziło sie.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Wiadōmość szkryftniyntŏ.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Weryfikacyjŏ wiadōmości niy podarziła sie.</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>Sztatus</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datōm</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źrōdło</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Z</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>niyznōme</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etyketa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadōmość</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kōmyntŏrz</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakcyjŏ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kwota</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datōm</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Zorta</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etyketa</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ôdebrane z</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ôdebrane ôd</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Płat do siebie</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(chyba etykety)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Wszyjske</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiej</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ôdebrane z</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inksze</translation>
    </message>
    <message>
        <source>Enter address, transaction id, or label to search</source>
        <translation>Wkludź adresa, idyntyfikatōr transakcyje abo etyketã coby wyszukać</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopiyruj adresã</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Kopiyruj &amp;etyketã</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Kopiyruj kwotã</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Kopiyruj ID transakcyje</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Edytuj etyketa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Zbiōr *.CSV (dane rozdzielane kōmami)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Przituplowany</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datōm</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Zorta</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etyketa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportowanie niy podarziło sie</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Poślij mōnety</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation>Nowŏ ôpłŏcka:</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>wychodny portmanyj</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportuj</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksportuj dane z aktywnyj szkarty do zbioru</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Backup niy podarził sie</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Pociep</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>The %s developers</source>
        <translation>Twōrcy %s</translation>
    </message>
    <message>
        <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
        <translation>Pozōr: Nec niy wydŏwŏ sie w połni zgodliwy! Niykerzi grubiŏrze wydajōm sie doświadczać niyprzileżytości.</translation>
    </message>
    <message>
        <source>Error loading %s</source>
        <translation>Feler wgrŏwaniŏ %s</translation>
    </message>
    <message>
        <source>Error loading %s: Private keys can only be disabled during creation</source>
        <translation>Feler wgrŏwaniŏ %s: Klucze prywatne mogōm być zastawiōne ino w czasie tworzyniŏ</translation>
    </message>
    <message>
        <source>Error loading %s: Wallet corrupted</source>
        <translation>Feler wgrŏwaniŏ %s: Portmanyj poprzniōny</translation>
    </message>
    <message>
        <source>Error loading %s: Wallet requires newer version of %s</source>
        <translation>Feler wgrŏwaniŏ %s: Portmanyj fołdruje nowszyj wersyje %s</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Feler wgrŏwaniŏ bazy blokōw</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feler</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Wgrŏwanie adres P2P...</translation>
    </message>
    <message>
        <source>Loading banlist...</source>
        <translation>Wgrŏwanie wykŏzu zaszperowanych...</translation>
    </message>
    <message>
        <source>Unsupported logging category %s=%s.</source>
        <translation>Niypodpiyranŏ kategoryjŏ registrowaniŏ %s=%s.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Weryfikacyjŏ blokōw...</translation>
    </message>
    <message>
        <source>Error: Disk space is low for %s</source>
        <translation>Feler: Za mało wolnego placu na dysku dlŏ %s</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Szkryftniyńcie transakcyji niy podarziło sie</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>To je eksperymyntalny softwer.</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transakcyjŏ za srogŏ</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Weryfikacyjŏ portmanyja(ōw)...</translation>
    </message>
    <message>
        <source>Warning: unknown new rules activated (versionbit %i)</source>
        <translation>Pozōr: aktywowano było niyznōme nowe prawidła (versionbit %i)</translation>
    </message>
    <message>
        <source>Total length of network version string (%i) exceeds maximum length (%i). Reduce the number or size of uacomments.</source>
        <translation>Imyntnŏ dugość kety wersyje (%i) przekrŏczŏ maksymalnõ dopuszczalnõ dugość (%i). Zmyńsz wielość abo miara parametra uacomment.</translation>
    </message>
    <message>
        <source>Starting network threads...</source>
        <translation>Sztartowanie wōntkōw necowych...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Niyznōmy nec ôkryślōny w -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Warning: Private keys detected in wallet {%s} with disabled private keys</source>
        <translation>Pozōr: Wykryto było klucze prywatne w portmanyju {%s} kery mŏ zastawiōne klucze prywatne</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Wgrŏwanie indeksu blokōw...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Wgrŏwanie portmanyja...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Pōnowne skanowanie</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Wgrŏwanie zakōńczōne</translation>
    </message>
</context>
</TS>